@@ -1,4 +1,5 @@
 <?php
+
 #################################################################
 #  Copyright notice
 #
@@ -24,33 +25,31 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
-
 namespace Baikal\Model\Config;
 
 class Database extends \Baikal\Model\Config {
-
     protected $aConstants = [
-        "PROJECT_SQLITE_FILE" => [
+        "sqlite_file" => [
             "type"    => "litteral",
             "comment" => "Define path to Baïkal Database SQLite file",
         ],
-        "PROJECT_DB_MYSQL" => [
+        "mysql" => [
             "type"    => "boolean",
             "comment" => "MySQL > Use MySQL instead of SQLite ?",
         ],
-        "PROJECT_DB_MYSQL_HOST" => [
+        "mysql_host" => [
             "type"    => "string",
             "comment" => "MySQL > Host, including ':portnumber' if port is not the default one (3306)",
         ],
-        "PROJECT_DB_MYSQL_DBNAME" => [
+        "mysql_dbname" => [
             "type"    => "string",
             "comment" => "MySQL > Database name",
         ],
-        "PROJECT_DB_MYSQL_USERNAME" => [
+        "mysql_username" => [
             "type"    => "string",
             "comment" => "MySQL > Username",
         ],
-        "PROJECT_DB_MYSQL_PASSWORD" => [
+        "mysql_password" => [
             "type"    => "string",
             "comment" => "MySQL > Password",
         ],
@@ -58,19 +57,23 @@ class Database extends \Baikal\Model\Config {
 
     # Default values
     protected $aData = [
-        "PROJECT_SQLITE_FILE"       => 'PROJECT_PATH_SPECIFIC . "db/db.sqlite"',
-        "PROJECT_DB_MYSQL"          => false,
-        "PROJECT_DB_MYSQL_HOST"     => "",
-        "PROJECT_DB_MYSQL_DBNAME"   => "",
-        "PROJECT_DB_MYSQL_USERNAME" => "",
-        "PROJECT_DB_MYSQL_PASSWORD" => "",
+        "sqlite_file"    => PROJECT_PATH_SPECIFIC . "db/db.sqlite",
+        "mysql"          => false,
+        "mysql_host"     => "",
+        "mysql_dbname"   => "",
+        "mysql_username" => "",
+        "mysql_password" => "",
     ];
 
+    function __construct() {
+        parent::__construct("database");
+    }
+
     function formMorphologyForThisModelInstance() {
         $oMorpho = new \Formal\Form\Morphology();
 
         $oMorpho->add(new \Formal\Element\Text([
-            "prop"       => "PROJECT_SQLITE_FILE",
+            "prop"       => "sqlite_file",
             "label"      => "SQLite file path",
             "validation" => "required",
             "inputclass" => "input-xxlarge",
@@ -78,30 +81,30 @@ class Database extends \Baikal\Model\Config {
         ]));
 
         $oMorpho->add(new \Formal\Element\Checkbox([
-            "prop"            => "PROJECT_DB_MYSQL",
+            "prop"            => "mysql",
             "label"           => "Use MySQL",
             "help"            => "If checked, Baïkal will use MySQL instead of SQLite.",
             "refreshonchange" => true,
         ]));
 
         $oMorpho->add(new \Formal\Element\Text([
-            "prop"  => "PROJECT_DB_MYSQL_HOST",
+            "prop"  => "mysql_host",
             "label" => "MySQL host",
             "help"  => "Host ip or name, including <strong>':portnumber'</strong> if port is not the default one (3306)"
         ]));
 
         $oMorpho->add(new \Formal\Element\Text([
-            "prop"  => "PROJECT_DB_MYSQL_DBNAME",
+            "prop"  => "mysql_dbname",
             "label" => "MySQL database name",
         ]));
 
         $oMorpho->add(new \Formal\Element\Text([
-            "prop"  => "PROJECT_DB_MYSQL_USERNAME",
+            "prop"  => "mysql_username",
             "label" => "MySQL username",
         ]));
 
         $oMorpho->add(new \Formal\Element\Password([
-            "prop"  => "PROJECT_DB_MYSQL_PASSWORD",
+            "prop"  => "mysql_password",
             "label" => "MySQL password",
         ]));
 
@@ -111,8 +114,4 @@ class Database extends \Baikal\Model\Config {
     function label() {
         return "Baïkal Database Settings";
     }
-
-    protected static function getDefaultConfig() {
-        throw new \Exception("Should never reach getDefaultConfig() on \Baikal\Model\Config\Database");
-    }
 }
