@@ -1,4 +1,5 @@
 <?php
+
 #################################################################
 #  Copyright notice
 #
@@ -24,13 +25,21 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
-
 namespace BaikalAdmin\Controller;
 
 class Users extends \Flake\Core\Controller {
-
     protected $aMessages = [];
 
+    /**
+     * @var \Baikal\Model\User
+     */
+    private $oModel;
+
+    /**
+     * @var \Formal\Form
+     */
+    private $oForm;
+
     function execute() {
         if ($this->actionEditRequested()) {
             $this->actionEdit();
@@ -46,7 +55,6 @@ class Users extends \Flake\Core\Controller {
     }
 
     function render() {
-
         $oView = new \BaikalAdmin\View\Users();
 
         # List of users
@@ -149,21 +157,20 @@ class Users extends \Flake\Core\Controller {
         $iUser = intval($aParams["delete"]);
 
         if ($this->actionDeleteConfirmed() !== false) {
-
             # catching Exception thrown when model already destroyed
-                # happens when user refreshes delete-page, for instance
+            # happens when user refreshes delete-page, for instance
 
             try {
                 $oUser = new \Baikal\Model\User($iUser);
                 $oUser->destroy();
             } catch (\Exception $e) {
                 # user is already deleted; silently discarding
+                error_log($e);
             }
 
             # Redirecting to admin home
             \Flake\Util\Tools::redirectUsingMeta($this->link());
         } else {
-
             $oUser = new \Baikal\Model\User($iUser);
             $this->aMessages[] = \Formal\Core\Message::warningConfirmMessage(
                 "Check twice, you're about to delete " . $oUser->label() . "</strong> from the database !",
