@@ -24,6 +24,8 @@
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
 
+use Symfony\Component\Yaml\Yaml;
+
 ini_set("session.cookie_httponly", 1);
 ini_set("display_errors", 0);
 ini_set("log_errors", 1);
@@ -40,7 +42,7 @@ if (file_exists(getcwd() . "/Core")) {
 }
 
 if (!file_exists(PROJECT_PATH_ROOT . 'vendor/')) {
-    die('<h1>Incomplete installation</h1><p>Ba&iuml;kal dependencies have not been installed. Please, execute "<strong>composer install</strong>" in the folder where you installed Ba&iuml;kal.');
+    die('<h1>Incomplete installation</h1><p>Ba&iuml;kal dependencies have not been installed. If you are a regular user, this means that you probably downloaded the wrong zip file.</p><p>To install the dependencies manually, execute "<strong>composer install</strong>" in the Ba&iuml;kal root folder.</p>');
 }
 
 require PROJECT_PATH_ROOT . 'vendor/autoload.php';
@@ -51,16 +53,22 @@ require PROJECT_PATH_ROOT . 'vendor/autoload.php';
 # Bootstrapping Baïkal
 \Baikal\Framework::bootstrap();
 
-if (!defined("BAIKAL_CARD_ENABLED") || BAIKAL_CARD_ENABLED !== true) {
+try {
+    $config = Yaml::parseFile(PROJECT_PATH_CONFIG . "baikal.yaml");
+} catch (\Exception $e) {
+    die('<h1>Incomplete installation</h1><p>Ba&iuml;kal is missing its configuration file, or its configuration file is unreadable.');
+}
+
+if (!isset($config['system']["card_enabled"]) || $config['system']["card_enabled"] !== true) {
     throw new ErrorException("Baikal CardDAV is disabled.", 0, 255, __FILE__, __LINE__);
 }
 
 $server = new \Baikal\Core\Server(
-    BAIKAL_CAL_ENABLED,
-    BAIKAL_CARD_ENABLED,
-    BAIKAL_DAV_AUTH_TYPE,
-    BAIKAL_AUTH_REALM,
+    $config['system']["cal_enabled"],
+    $config['system']["card_enabled"],
+    $config['system']["dav_auth_type"],
+    $config['system']["auth_realm"],
     $GLOBALS['DB']->getPDO(),
-    BAIKAL_CARD_BASEURI
+    PROJECT_BASEURI . 'card.php/'
 );
 $server->start();
